pub enum AddPeerError {
Capacity,
InvalidPublicKey,
}Expand description
Error returned when adding a peer to the MAC peer registry.
Variants
Capacity
The peer-registry table is full.
InvalidPublicKey
The public-key bytes do not decode to a valid Ed25519 point on the curve.