ReplayVerdict

Enum ReplayVerdict 

pub enum ReplayVerdict {
    Accept,
    Replay,
    OutOfWindow,
    Stale,
}
Result of checking a packet against a replay window.

Variants



Accept

The packet is acceptable.



Replay

The exact counter/MIC pair was already accepted.



OutOfWindow

The counter is too far behind the tracked window.



Stale

The replay state is too stale to safely accept backward-window traffic.