forwarding_dup_key

Function forwarding_dup_key 

pub fn forwarding_dup_key(frame: &[u8]) -> Option<DupCacheKey>
Routing identity of a frame, parsing its header first.

None when the frame does not parse, or for the reasons forwarding_dup_key_parsed gives.