RxMetadata

Struct RxMetadata 

pub struct RxMetadata { /* private fields */ }
Local physical-layer observations captured when a frame was received.

SNR is represented in centibels (0.1 dB units). This is finer than whole decibels, but still compact and integer-friendly. Some common LoRa radios report packet SNR in quarter-dB steps; converting those readings into centibels may therefore introduce a small rounding error.

Implementations

Source

impl RxMetadata

pub fn new( rssi: Option<i16>, snr: Option<Snr>, lqi: Option<NonZeroU8>, received_at_ms: Option<u64>, ) -> Self

pub fn rssi(&self) -> Option<i16>

pub fn snr(&self) -> Option<Snr>

pub fn lqi(&self) -> Option<NonZeroU8>

pub fn received_at_ms(&self) -> Option<u64>