pub struct ModeledNetwork { /* private fields */ }Expand description
Shared simulated network with scheduled delivery, jitter, packet loss, and coarse collision modeling.
Implementations
Sourceimpl ModeledNetwork
impl ModeledNetwork
Sourcepub fn with_clock(clock: DummyClock) -> Self
pub fn with_clock(clock: DummyClock) -> Self
Create an empty modeled network using a caller-supplied shared clock.
Sourcepub fn clock(&self) -> DummyClock
pub fn clock(&self) -> DummyClock
Return the shared modeled clock.
Sourcepub fn advance_ms(&self, delta_ms: u64)
pub fn advance_ms(&self, delta_ms: u64)
Advance the shared simulation time.
Sourcepub fn reseed(&self, seed: u64)
pub fn reseed(&self, seed: u64)
Override the deterministic RNG seed used for loss/jitter sampling.
Sourcepub fn add_radio(&self) -> ModeledRadio
pub fn add_radio(&self) -> ModeledRadio
Add a modeled radio with default limits.
Sourcepub fn add_radio_with_config(
&self,
max_frame_size: usize,
t_frame_ms: u32,
) -> ModeledRadio
pub fn add_radio_with_config( &self, max_frame_size: usize, t_frame_ms: u32, ) -> ModeledRadio
Add a modeled radio with explicit frame-size and airtime limits.
Sourcepub fn connect(&self, from: usize, to: usize)
pub fn connect(&self, from: usize, to: usize)
Connect from to to using the default modeled link profile.
Sourcepub fn connect_bidirectional(&self, a: usize, b: usize)
pub fn connect_bidirectional(&self, a: usize, b: usize)
Connect two radios in both directions using the default modeled link profile.
Sourcepub fn disconnect(&self, from: usize, to: usize)
pub fn disconnect(&self, from: usize, to: usize)
Remove the directed link from from to to.
Sourcepub fn set_link_profile(
&self,
from: usize,
to: usize,
profile: ModeledLinkProfile,
)
pub fn set_link_profile( &self, from: usize, to: usize, profile: ModeledLinkProfile, )
Configure one directed link with an explicit modeled profile.
Sourcepub fn has_pending_deliveries(&self) -> bool
pub fn has_pending_deliveries(&self) -> bool
Return whether any future deliveries are still pending.